cole Library Reference Manual
Prev | Chapter 1. Introduction | Next

# Features

cole 2.x release series:

- Can open Structured Storage files generated with programs from Microsoft, StarDivision and FlashPix.

- Is written in C, for better performance.

- Should compile in UNIX-like systems with ANSI C libraries and a ANSI C compiler.

- Has a new good-looking API, modelled after ANSI C `stdio.h` routines.

- Uses standard automake, autoconf and libtool generated files.

- Provides a standard `configure` script.

- Builds shared (dynamic) libraries if the plattform and libtool support it.

- Provides standard targets in the Makefile (ie. `install`, `clean`, etc).

- Can use (thanks to the `configure` script) plattform dependent system calls for better performance.

Prev | Home | Next
Introduction | Up | Requirements to compile